@@ -8,6 +8,34 @@ import json
 import re
 
 
+def decrypt_github_file(repo, password, select_file):
+    # Get file path
+    file_path = get_file_path(repo, select_file)
+
+    # Check if file exists
+    if not file_path:
+        exit()
+
+    # Create the enc folder if it does not exist
+    enc_folder = os.path.join(".", "enc")
+    if not os.path.exists(enc_folder):
+        os.makedirs(enc_folder)
+
+    # Download and decrypt data from Github
+    download_file(
+        repo=repo, github_file_path=os.path.join(file_path), download_path=enc_folder,
+    )
+
+    # Decrypt data from downloaded file
+    with open(os.path.join(enc_folder, select_file), "rb") as f:
+        encrypted_data = (f.readline().strip(), f.readline().strip())
+
+    # Decrypt data
+    aes = AESCrypt(password)
+    decrypted_data = aes.decrypt(encrypted_data)
+    return decrypted_data.decode(encoding="utf-8")
+
+
 def get_file_path(repo, select_file):
     """
     Retrieve the path of the input file from a GitHub repository.
